@@ -97,6 +97,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'AK1' => 'A&K',
         '00'  => 'Accent',
         'ACC' => 'Accesstyle',
+        'ACD' => 'ACD',
         'AE'  => 'Ace',
         'AC'  => 'Acer',
         'ACL' => 'Aceline',
@@ -126,6 +127,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'AW'  => 'Aiwa',
         '85'  => 'Aiuto',
         'U7'  => 'AIDATA',
+        'AL1' => 'AileTV',
+        'AL2' => 'AI+',
         'AK'  => 'Akai',
         'Q3'  => 'AKIRA',
         '1A'  => 'Alba',
@@ -179,6 +182,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '9Y'  => 'Aocos',
         'AOW' => 'Aocwei',
         'AP'  => 'Apple',
+        'APS' => 'ApoloSign',
         'ARC' => 'Arçelik',
         'AR'  => 'Archos',
         'AB'  => 'Arian Space',
@@ -235,6 +239,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XU'  => 'AUX',
         'BAC' => 'Backcell',
         'BFF' => 'BAFF',
+        'BNC' => 'BNCF',
         'BO'  => 'BangOlufsen',
         'BN'  => 'Barnes & Noble',
         'BAR' => 'BARTEC',
@@ -253,6 +258,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'BEK' => 'Beko',
         '2X'  => 'Benco',
         'BQ'  => 'BenQ',
+        'BQL' => 'Bqeel',
         'BS'  => 'BenQ-Siemens',
         '4Y'  => 'Benzo',
         'XJ'  => 'Benesse',
@@ -326,8 +332,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'BYD' => 'BYD',
         'C9'  => 'CAGI',
         'CAD' => 'CADENA',
+        'CAL' => 'CALME',
+        'CAI' => 'Caixun',
         'CT'  => 'Capitel',
         'GRD' => 'G-Guard',
+        'GVL' => 'G-Vill',
         'G3'  => 'CG Mobile',
         '37'  => 'CGV',
         'CP'  => 'Captiva',
@@ -388,6 +397,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'CC'  => 'ConCorde',
         'C5'  => 'Condor',
         'C5M' => 'C5 Mobile',
+        'COE' => 'Cogeco',
         '4C'  => 'Conquest',
         'COG' => 'CONSUNG',
         '3C'  => 'Contixo',
@@ -411,6 +421,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '33'  => 'Clementoni',
         'CR'  => 'CreNova',
         'CX'  => 'Crescent',
+        'CRE' => 'Crestron',
         'CK'  => 'Cricket',
         'CM'  => 'Crius Mea',
         'CMF' => 'CMF',
@@ -438,9 +449,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'D1'  => 'Datsun',
         'DZ'  => 'Dazen',
         'DAS' => 'DASS',
+        'DAW' => 'Dawlance',
         'DB'  => 'Dbtel',
         'DBP' => 'DbPhone',
         'DCO' => 'Dcode',
+        'DEC' => 'DEC',
         'DL'  => 'Dell',
         'DL0' => 'DL',
         'DE'  => 'Denver',
@@ -452,6 +465,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'DEY' => 'DEYI',
         'DEN' => 'Denali',
         'DEA' => 'DEALDIG',
+        'DNK' => 'Denka',
         '8D'  => 'DF',
         'DGT' => 'DGTEC',
         'DG'  => 'Dialog',
@@ -506,6 +520,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'DR1' => 'DreamStar',
         'DTA' => 'Dtac',
         'DU'  => 'Dune HD',
+        'DUO' => 'DuoTV',
         'UD'  => 'DUNNS Mobile',
         'DUU' => 'Duubee',
         'DUR' => 'Durabook',
@@ -515,9 +530,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'DTE' => 'D-Tech',
         'DLI' => 'D-Link',
         'ENO' => 'eNOVA',
+        'IN4' => 'Inno Hit',
         'IN2' => 'iNOVA',
         'IN3' => 'inovo',
         'INH' => 'Inhon',
+        'IND' => 'Indurama',
         'EB'  => 'E-Boda',
         'EJ'  => 'Engel',
         'ENA' => 'ENACOM',
@@ -538,7 +555,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         '35'  => 'ECON',
         'ECC' => 'ECOO',
         'ZZ'  => 'ecom',
+        'ECS' => 'EcoStar',
         'EDE' => 'Edenwood',
+        'EDX' => 'Edanix',
         'E6'  => 'EE',
         'GW'  => 'EGL',
         'EGO' => 'EGOTEK',
@@ -574,6 +593,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'EPK' => 'Epic',
         'XP'  => 'Epson',
         'EPH' => 'Ephone',
+        'EPL' => 'Eplutus',
         'E7'  => 'Ergo',
         'EC'  => 'Ericsson',
         '05'  => 'Erisson',
@@ -628,6 +648,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '9R'  => 'FaRao Pro',
         'FAR' => 'Farassoo',
         'FB'  => 'Fantec',
+        'FAN' => 'Fanvace',
         'FE'  => 'Fengxiang',
         'FEN' => 'Fenoti',
         'F7'  => 'Fero',
@@ -640,6 +661,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'FX'  => 'Finlux',
         'F3'  => 'FireFly Mobile',
         'F8'  => 'FISE',
+        'FIS' => 'Fision',
         'FIT' => 'FITCO',
         'FLM' => 'Filimo',
         'FIL' => 'FILIX',
@@ -661,12 +683,14 @@ abstract class AbstractDeviceParser extends AbstractParser
         'FR'  => 'Forstar',
         'RF'  => 'Fortis',
         'FRT' => 'FortuneShip',
+        'FOX' => 'FOX',
         'FO'  => 'Foxconn',
         'FOD' => 'FoxxD',
         'FJ'  => 'FOODO',
         'FOS' => 'FOSSiBOT',
         'FRE' => 'free',
         'FT'  => 'Freetel',
+        'FTH' => 'FRESH',
         'FEY' => 'FreeYond',
         'FRU' => 'Frunsi',
         'F4'  => 'F&U',
@@ -683,6 +707,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'FXT' => 'Fxtec',
         'GT'  => 'G-TiDE',
         'G9'  => 'G-Touch',
+        'GTB' => 'G-Tab',
         'GFO' => 'Gfone',
         'GTM' => 'GTMEDIA',
         'GTX' => 'GTX',
@@ -692,12 +717,15 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GA'  => 'Gateway',
         '99'  => 'Galaxy Innovations',
         'GA1' => 'Galactic',
+        'GAT' => 'Galatec',
         'GAM' => 'Gamma',
         'GAZ' => 'Gazer',
+        'GAL' => 'Gazal',
         'GEA' => 'Geanee',
         'GEN' => 'Geant',
         'GD'  => 'Gemini',
         'GN'  => 'General Mobile',
+        'GD1' => 'Genius Devices',
         '2G'  => 'Genesis',
         'GEP' => 'Geo Phone',
         'G2'  => 'GEOFOX',
@@ -716,6 +744,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GI'  => 'Gionee',
         'GIR' => 'GIRASOLE',
         'G4'  => 'Globex',
+        'GL2' => 'GlobalSec',
         'GLB' => 'Globmall',
         'GME' => 'GlocalMe',
         '38'  => 'GLONYX',
@@ -755,6 +784,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GU'  => 'Grundig',
         'GV'  => 'Gtel',
         'CUO' => 'Guophone',
+        'CUD' => 'CUD',
         'GVC' => 'GVC Pro',
         'H13' => 'H133',
         '9Z'  => 'H96',
@@ -813,6 +843,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'H0'  => 'Hometech',
         'HLB' => 'HOLLEBERG',
         'HM'  => 'Homtom',
+        'HM1' => 'HOMII',
         'HOP' => 'Hopeland',
         'HZ'  => 'Hoozo',
         'HOR' => 'Horion',
@@ -826,6 +857,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'JH'  => 'HOTREALS',
         'HW'  => 'How',
         'WH'  => 'Honeywell',
+        'HNR' => 'Honor',
         'HON' => 'HongTop',
         'HOG' => 'HONKUAHG',
         'HP'  => 'HP',
@@ -860,6 +892,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '7I'  => 'iBrit',
         'IBO' => 'ibowin',
         'I2'  => 'IconBIT',
+        'ING' => 'Icone Gold',
         'IC'  => 'iDroid',
         'IDI' => 'iDino',
         '6Z'  => 'iData',
@@ -891,6 +924,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'IW'  => 'iNew',
         'IF'  => 'Infinix',
         'INF' => 'Infiniton',
+        'IPR' => 'InfinityPro',
         'I0'  => 'InFocus',
         'IN1' => 'InFone',
         'II'  => 'Inkti',
@@ -942,7 +976,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'JA'  => 'JAY-Tech',
         'JAM' => 'Jambo',
         'KJ'  => 'Jiake',
-        'JD'  => 'Jedi',
+        'JD'  => 'Jide',
         'JEE' => 'Jeep',
         'J6'  => 'Jeka',
         'JF'  => 'JFone',
@@ -958,6 +992,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'JOY' => 'JoySurf',
         'UJ'  => 'Juniper Systems',
         'J5'  => 'Just5',
+        'JUS' => 'JUSYEA',
         '7J'  => 'Jumper',
         'JPA' => 'JPay',
         'JV'  => 'JVC',
@@ -1001,7 +1036,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         'KC'  => 'Kocaso',
         'KK'  => 'Kodak',
         'KG'  => 'Kogan',
+        'KGT' => 'KGTEL',
         'KM'  => 'Komu',
+        'KMC' => 'KMC',
         'KO'  => 'Konka',
         'KW'  => 'Konrow',
         'KB'  => 'Koobee',
@@ -1017,6 +1054,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'WK'  => 'KRIP',
         'KRA' => 'Kraft',
         'KH'  => 'KT-Tech',
+        'KTC' => 'KTC',
         'Z6'  => 'KUBO',
         'KUG' => 'KuGou',
         'K8'  => 'Kuliao',
@@ -1087,6 +1125,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'LU'  => 'Lumus',
         'LUM' => 'Lumitel',
         'L9'  => 'Luna',
+        'LNN' => 'LUNNEN',
         'LUO' => 'LUO',
         'LR'  => 'Luxor',
         'LY'  => 'LYF',
@@ -1103,6 +1142,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MAG' => 'MAG',
         'MA2' => 'MAGCH',
         '6Y'  => 'Magicsee',
+        'MA4' => 'Magenta',
         '23'  => 'Magnus',
         'NH'  => 'Manhattan',
         'MAN' => 'Mango',
@@ -1130,6 +1170,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'YM'  => 'Maze Speed',
         '87'  => 'Malata',
         'MAU' => 'Maunfeld',
+        'MCL' => 'McLaut',
         '28'  => 'MBOX',
         'FK'  => 'MBI',
         'MBK' => 'MBK',
@@ -1157,6 +1198,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MEO' => 'MEO',
         'MX'  => 'MEU',
         'MES' => 'MESWAO',
+        'MII' => 'MIIA',
         'MI'  => 'MicroMax',
         'MIP' => 'mipo',
         'MS'  => 'Microsoft',
@@ -1167,6 +1209,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MIN' => 'Mint',
         'MO'  => 'Mio',
         'MOD' => 'Moondrop',
+        'MOR' => 'MORTAL',
         'X7'  => 'Mione',
         'M7'  => 'Miray',
         'MIT' => 'Mitchell & Brown',
@@ -1213,6 +1256,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MLB' => 'multibox',
         '1R'  => 'Multilaser',
         'MPS' => 'MultiPOS',
+        'MLT' => 'MULTYNET',
         '1M'  => 'MYFON',
         'MY1' => 'myPhone (PL)',
         'MY'  => 'MyPhone (PH)',
@@ -1248,6 +1292,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '1N'  => 'Neomi',
         '7Q'  => 'Neon IQ',
         '8F'  => 'Neolix',
+        'NES' => 'Nesons',
         'NET' => 'NetBox',
         'NWT' => 'NETWIT',
         'NA'  => 'Netgear',
@@ -1266,6 +1311,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XB'  => 'NEXBOX',
         'NX'  => 'Nexian',
         '7X'  => 'Nexa',
+        '7XR' => 'Nexar',
         'N8'  => 'NEXON',
         'N2'  => 'Nextbit',
         'NT'  => 'NextBook',
@@ -1287,6 +1333,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'N6'  => 'Nobby',
         'NOC' => 'Novacom',
         'NOS' => 'NoviSea',
+        'NO2' => 'NOVIS',
         'NOV' => 'Novey',
         'NO1' => 'NOVO',
         '57'  => 'Nubia',
@@ -1422,7 +1469,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'PIX' => 'PIXPRO',
         'QP'  => 'Pico',
         'PIR' => 'PIRANHA',
-        'PIN' => 'PINE',
+        'PIN' => 'PINE64',
         '9P'  => 'Planet Computers',
         'PLA' => 'Play Now',
         'PY'  => 'Ployer',
@@ -1446,9 +1493,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         '3P'  => 'Positivo BGH',
         '3F'  => 'Porsche',
         'PRT' => 'Portfolio',
+        'PPD' => 'PPDS',
         'P3'  => 'PPTV',
         'FP'  => 'Premio',
-        'PR1' => 'Premier',
+        'PR2' => 'PREMIER',
+        'PR1' => 'Premier Star',
         'PR'  => 'Prestigio',
         'P9'  => 'Primepad',
         'PRM' => 'PRIME',
@@ -1473,6 +1522,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'QB'  => 'Q.Bell',
         'QI'  => 'Qilive',
         'QIN' => 'QIN',
+        'QIW' => 'Qiuwoky',
         'QM'  => 'QMobile',
         'QT'  => 'Qtek',
         'Q9'  => 'QTECH',
@@ -1483,6 +1533,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'QUI' => 'Quipus',
         'QO'  => 'Qumo',
         'UQ'  => 'Qubo',
+        'QUP' => 'Qupi',
         'YQ'  => 'QLink',
         'QY'  => 'Qnet Mobile',
         'WJ'  => 'Qware',
@@ -1493,6 +1544,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '0R'  => 'Raspberry',
         'R9'  => 'Ravoz',
         'RZ'  => 'Razer',
+        'RAZ' => 'RAZZ',
         '95'  => 'Rakuten',
         'RAY' => 'Raylandz',
         'RC'  => 'RCA Tablets',
@@ -1538,6 +1590,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ROI' => 'ROiK',
         'RK'  => 'Roku',
         'R3'  => 'Rombica',
+        'RUA' => 'Romsat',
         'R5'  => 'Ross&Moor',
         'RO'  => 'Rover',
         'R6'  => 'RoverPad',
@@ -1549,6 +1602,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'RUG' => 'Ruggex',
         'RUT' => 'RuggeTech',
         'RU'  => 'Runbo',
+        'RUN' => 'RunGee',
         'RUP' => 'Rupa',
         'RL'  => 'Ruio',
         'RY'  => 'Ryte',
@@ -1570,6 +1624,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'SA'  => 'Samsung',
         'SAT' => 'Samtech',
         'SAM' => 'Samtron',
+        'SAB' => 'Sambox',
         'SNA' => 'SNAMI',
         'S0'  => 'Sanei',
         '12'  => 'Sansui',
@@ -1594,6 +1649,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'SL'  => 'Selfix',
         '0S'  => 'SEMP TCL',
         'S1'  => 'Sencor',
+        'SNM' => 'Sencrom',
         'SN'  => 'Sendo',
         '01'  => 'Senkatel',
         'S6'  => 'Senseit',
@@ -1674,11 +1730,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         '6S'  => 'Spectrum',
         '43'  => 'Spectralink',
         'SP'  => 'Spice',
+        'SPD' => 'Spider',
         '84'  => 'Sprint',
         'SPU' => 'SPURT',
         'QS'  => 'SQOOL',
         'S4'  => 'Star',
         'OL'  => 'Starlight',
+        'STA' => 'Star-Light',
         '18'  => 'Starmobile',
         '2S'  => 'Starway',
         '45'  => 'Starwind',
@@ -1693,11 +1751,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         '69'  => 'Stylo',
         'STI' => 'Stilevs',
         '9S'  => 'Sugar',
+        'SUA' => 'SUAAT',
         'SUR' => 'Surge',
         'SUF' => 'Surfans',
         '06'  => 'Subor',
         'SUT' => 'SULPICE TV',
         'SZ'  => 'Sumvision',
+        'SNG' => 'SUNGATE',
         '0H'  => 'Sunstech',
         'S3'  => 'SunVan',
         '5S'  => 'Sunvell',
@@ -1721,6 +1781,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '1W'  => 'Swisstone',
         'SWO' => 'SWOFY',
         'SSK' => 'SSKY',
+        'SSM' => 'Ssmart',
         'SYC' => 'Syco',
         'SM'  => 'Symphony',
         '4S'  => 'Syrox',
@@ -1817,6 +1878,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TOU' => 'Touch Plus',
         '5R'  => 'Transpeed',
         'T6'  => 'TrekStor',
+        'TRP' => 'Trecfone',
         'T3'  => 'Trevi',
         'TRI' => 'TriaPlay',
         'TJ'  => 'Trifone',
@@ -1826,6 +1888,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '11'  => 'True',
         'JT'  => 'True Slim',
         'J1'  => 'Trio',
+        'TRC' => 'Tricolor',
         'THT' => 'Tsinghua Tongfang',
         '5C'  => 'TTEC',
         'TTF' => 'TTfone',
@@ -1840,6 +1903,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TUV' => 'Tuvio',
         'TUC' => 'TUCSON',
         '2U'  => 'Türk Telekom',
+        'TUR' => 'Türksat',
         'TV'  => 'TVC',
         'TVP' => 'TV+',
         'TW'  => 'TWM',
@@ -1885,6 +1949,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '5V'  => 'VAIO',
         'WV'  => 'VAVA',
         'VA'  => 'Vastking',
+        'VAS' => 'VASOUN',
         'VP'  => 'Vargo',
         'VC'  => 'Vankyo',
         'VAL' => 'VALEM',
@@ -1922,6 +1987,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VIE' => 'Viendo',
         'VIK' => 'VIKUSHA',
         'V7'  => 'Vinga',
+        'V7T' => 'V7',
         'V3'  => 'Vinsoc',
         'XD'  => 'Vinabox',
         'FV'  => 'Vios',
@@ -1941,6 +2007,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VZ'  => 'Vizio',
         'VIZ' => 'Vizmo',
         'VIT' => 'Vityaz',
+        'VTM' => 'Vitumi',
         '9V'  => 'Vision Touch',
         'VIS' => 'Vision Technology',
         'VST' => 'Visitech',
@@ -1967,6 +2034,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VOR' => 'Vormor',
         'V1'  => 'Voto',
         'Z7'  => 'VOX',
+        'VOI' => 'VOIX',
         'VO'  => 'Voxtel',
         'VY'  => 'Voyo',
         'VOL' => 'Völfen',
@@ -1987,6 +2055,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'WLT' => 'Waltham',
         'WAL' => 'Waltter',
         'WAI' => 'Wainyok',
+        'WAT' => 'waipu.tv',
         'WHI' => 'White Mobile',
         'WHO' => 'Whoop',
         'WBL' => 'We. by Loewe.',
@@ -2031,6 +2100,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XQ'  => 'X-AGE',
         'XEL' => 'XElectron',
         'X3'  => 'X-BO',
+        'XBI' => 'XB',
         'XMO' => 'X-Mobile',
         'XT'  => 'X-TIGI',
         'XV'  => 'X-View',
@@ -2079,6 +2149,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'YUN' => 'YUNDOO',
         'YUS' => 'YunSong',
         'YUM' => 'YUMKEM',
+        'YIK' => 'YIKEMI',
         'YU'  => 'Yuandao',
         'YS'  => 'Yusun',
         'YJ'  => 'YASIN',
@@ -2086,6 +2157,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '0Z'  => 'Zatec',
         '2Z'  => 'Zaith',
         'ZAM' => 'Zamolxe',
+        'ZAL' => 'ZALA',
         'ZZB' => 'ZZB',
         'ZEA' => 'Zealot',
         'PZ'  => 'Zebra',
@@ -2099,10 +2171,12 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ZI'  => 'Zidoo',
         'FZ'  => 'ZIFRO',
         'ZIF' => 'ZIFFLER',
+        'ZIO' => 'ZIOVO',
         'ZX'  => 'Ziox',
         'ZIK' => 'ZIK',
         'ZKI' => 'Z-Kai',
         'ZIG' => 'Zigo',
+        'ZIM' => 'Zimmer',
         'ZIN' => 'Zinox',
         'ZO'  => 'Zonda',
         'ZW'  => 'Zonko',
@@ -2179,7 +2253,7 @@ abstract class AbstractDeviceParser extends AbstractParser
      */
     public static function getDeviceName(int $deviceType): string
     {
-        $deviceName = \array_search($deviceType, self::$deviceTypes);
+        $deviceName = \array_search($deviceType, self::$deviceTypes, true);
 
         if (\is_string($deviceName)) {
             return $deviceName;
@@ -2235,7 +2309,7 @@ abstract class AbstractDeviceParser extends AbstractParser
      */
     public static function getShortCode(string $brand): string
     {
-        return (string) \array_search($brand, self::$deviceBrands) ?: '';
+        return (string) \array_search($brand, self::$deviceBrands, true) ?: '';
     }
 
     /**
@@ -2267,10 +2341,9 @@ abstract class AbstractDeviceParser extends AbstractParser
             return $this->getResult();
         }
 
-        $brand   = '';
-        $regexes = $this->getRegexes();
+        $brand = '';
 
-        foreach ($regexes as $brand => $regex) {
+        foreach ($this->getRegexes() as $brand => $regex) {
             $matches = $this->matchUserAgent($regex['regex']);
 
             if ($matches) {
@@ -2278,6 +2351,8 @@ abstract class AbstractDeviceParser extends AbstractParser
             }
         }
 
+        $brand = (string) $brand;
+
         if (empty($matches)) {
             $this->deviceType = $resultClientHint['deviceType'] ?? null;
 
@@ -2285,7 +2360,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         }
 
         if ('Unknown' !== $brand) {
-            if (!\in_array($brand, self::$deviceBrands)) {
+            if (!\in_array($brand, self::$deviceBrands, true)) {
                 // This Exception should never be thrown. If so a defined brand name is missing in $deviceBrands
                 throw new \Exception(\sprintf(
                     "The brand with name '%s' should be listed in deviceBrands array. Tried to parse user agent: %s",
@@ -2294,7 +2369,7 @@ abstract class AbstractDeviceParser extends AbstractParser
                 )); // @codeCoverageIgnore
             }
 
-            $this->brand = (string) $brand;
+            $this->brand = $brand;
         }
 
         if (isset($regex['device']) && \array_key_exists($regex['device'], self::$deviceTypes)) {
@@ -2324,7 +2399,7 @@ abstract class AbstractDeviceParser extends AbstractParser
 
             $this->model = $this->buildModel($modelRegex['model'], $modelMatches);
 
-            if (isset($modelRegex['brand']) && \in_array($modelRegex['brand'], self::$deviceBrands)) {
+            if (isset($modelRegex['brand']) && \in_array($modelRegex['brand'], self::$deviceBrands, true)) {
                 $this->brand = (string) $modelRegex['brand'];
             }
 
@@ -2367,7 +2442,7 @@ abstract class AbstractDeviceParser extends AbstractParser
             $formFactors        = $this->clientHints->getFormFactors();
 
             foreach (self::$clientHintFormFactorsMapping as $formFactor => $deviceType) {
-                if (\in_array($formFactor, $formFactors)) {
+                if (\in_array($formFactor, $formFactors, true)) {
                     $detectedDeviceType = $deviceType;
 
                     break;
