@@ -13,6 +13,7 @@ declare(strict_types=1);
 namespace DeviceDetector\Tests\Parser\Client;
 
 use DeviceDetector\Parser\Client\MobileApp;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use Spyc;
 
@@ -21,18 +22,23 @@ class MobileAppTest extends TestCase
     /**
      * @dataProvider getFixtures
      */
+    #[DataProvider('getFixtures')]
     public function testParse(string $useragent, array $client): void
     {
         $mobileAppParser = new MobileApp();
-        $mobileAppParser->setVersionTruncation(MobileApp::VERSION_TRUNCATION_NONE);
+        $mobileAppParser::setVersionTruncation(MobileApp::VERSION_TRUNCATION_NONE);
         $mobileAppParser->setUserAgent($useragent);
         $this->assertEquals($client, $mobileAppParser->parse());
     }
 
-    public function getFixtures(): array
+    public static function getFixtures(): array
     {
         $fixtureData = Spyc::YAMLLoad(\realpath(__DIR__) . '/fixtures/mobile_app.yml');
 
+        $fixtureData = \array_map(static function (array $item): array {
+            return ['useragent' => $item['user_agent'], 'client' => $item['client']];
+        }, $fixtureData);
+
         return $fixtureData;
     }
 
